Credits
========

The following is an alphabetical list of people who have contributed directly to this project or were otherwise helpful in its creation/maintenance.

u/MurdoMaclachlan
^^^^^^^^^^^^^^^^^^

`Website <https://murdomaclachlan.github.io/website>`_

- Original creator and primary maintainer
